==> Xalan-C_1_6-src.tar.gz: xml-xalan/c/src/xalanc/XPath/FunctionConcat.cpp <==
/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2000-2002 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Xalan" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation and was
 * originally based on software copyright (c) 1999, International
 * Business Machines, Inc., http://www.ibm.com.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */
#include "FunctionConcat.hpp"



#include "XObjectFactory.hpp"



XALAN_CPP_NAMESPACE_BEGIN



FunctionConcat::FunctionConcat()
{
}



FunctionConcat::~FunctionConcat()
{
}



XObjectPtr
FunctionConcat::execute(
			XPathExecutionContext&	executionContext,
			XalanNode*				/* context */,			
			const XObjectPtr		arg1,
			const XObjectPtr		arg2,
			const LocatorType*		/* locator */) const
{
	assert(arg1.null() == false && arg2.null() == false);	

	XPathExecutionContext::GetAndReleaseCachedString	theResult(executionContext);

	XalanDOMString&		theString = theResult.get();

	arg1->str(theString);
	arg2->str(theString);

	return executionContext.getXObjectFactory().createString(theResult);
}



XObjectPtr
FunctionConcat::execute(
			XPathExecutionContext&	executionContext,
			XalanNode*				/* context */,			
			const XObjectPtr		arg1,
			const XObjectPtr		arg2,
			const XObjectPtr		arg3,
			const LocatorType*		/* locator */) const
{
	assert(arg1.null() == false && arg2.null() == false && arg3.null() == false);	

	XPathExecutionContext::GetAndReleaseCachedString	theResult(executionContext);

	XalanDOMString&			theString = theResult.get();

	arg1->str(theString);
	arg2->str(theString);
	arg3->str(theString);

	return executionContext.getXObjectFactory().createString(theResult);
}



XObjectPtr
FunctionConcat::execute(
			XPathExecutionContext&			executionContext,
			XalanNode*						/* context */,
			const XObjectArgVectorType&		args,
			const LocatorType*				/* locator */) const
{
	const XObjectArgVectorType::const_iterator	theEnd = args.end();

	XPathExecutionContext::GetAndReleaseCachedString	theResult(executionContext);

	XalanDOMString&		theString = theResult.get();

	XObjectArgVectorType::const_iterator	i = args.begin();

	for(; i != theEnd; ++i)
	{
		(*i)->str(theString);
	}

	return executionContext.getXObjectFactory().createString(theResult);
}



#if defined(XALAN_NO_COVARIANT_RETURN_TYPE)
Function*
#else
FunctionConcat*
#endif
FunctionConcat::clone() const
{
	return new FunctionConcat(*this);
}



const XalanDOMString
FunctionConcat::getError() const
{
	return StaticStringToDOMString(XALAN_STATIC_UCODE_STRING("The concat() function takes at least two arguments!"));
}



XALAN_CPP_NAMESPACE_END

==> Xalan-C_1_9_0-src.tar.gz: xml-xalan/c/src/xalanc/XPath/FunctionConcat.cpp <==
/*
 * Copyright 1999-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "FunctionConcat.hpp"



#include <xalanc/PlatformSupport/XalanMessageLoader.hpp>



#include "XObjectFactory.hpp"



XALAN_CPP_NAMESPACE_BEGIN



FunctionConcat::FunctionConcat()
{
}



FunctionConcat::~FunctionConcat()
{
}



XObjectPtr
FunctionConcat::execute(
			XPathExecutionContext&	executionContext,
			XalanNode*				/* context */,			
			const XObjectPtr		arg1,
			const XObjectPtr		arg2,
			const LocatorType*		/* locator */) const
{
	assert(arg1.null() == false && arg2.null() == false);	

	XPathExecutionContext::GetAndReleaseCachedString	theResult(executionContext);

	XalanDOMString&		theString = theResult.get();

	arg1->str(theString);
	arg2->str(theString);

	return executionContext.getXObjectFactory().createString(theResult);
}



XObjectPtr
FunctionConcat::execute(
			XPathExecutionContext&	executionContext,
			XalanNode*				/* context */,			
			const XObjectPtr		arg1,
			const XObjectPtr		arg2,
			const XObjectPtr		arg3,
			const LocatorType*		/* locator */) const
{
	assert(arg1.null() == false && arg2.null() == false && arg3.null() == false);	

	XPathExecutionContext::GetAndReleaseCachedString	theResult(executionContext);

	XalanDOMString&			theString = theResult.get();

	arg1->str(theString);
	arg2->str(theString);
	arg3->str(theString);

	return executionContext.getXObjectFactory().createString(theResult);
}



XObjectPtr
FunctionConcat::execute(
			XPathExecutionContext&			executionContext,
			XalanNode*						/* context */,
			const XObjectArgVectorType&		args,
			const LocatorType*				/* locator */) const
{
	const XObjectArgVectorType::const_iterator	theEnd = args.end();

	XPathExecutionContext::GetAndReleaseCachedString	theResult(executionContext);

	XalanDOMString&		theString = theResult.get();

	XObjectArgVectorType::const_iterator	i = args.begin();

	for(; i != theEnd; ++i)
	{
		(*i)->str(theString);
	}

	return executionContext.getXObjectFactory().createString(theResult);
}



#if defined(XALAN_NO_COVARIANT_RETURN_TYPE)
Function*
#else
FunctionConcat*
#endif
FunctionConcat::clone(MemoryManagerType&    theManager) const
{
	return XalanCopyConstruct(theManager, *this);
}



const XalanDOMString&
FunctionConcat::getError(XalanDOMString&    theResult) const
{
	return XalanMessageLoader::getMessage(
                XalanMessages::FunctionTakes2ArgsAtLeast_1Param,
                theResult,
                "concat()");
}



XALAN_CPP_NAMESPACE_END
